@@ -3,6 +3,7 @@
 from __future__ import annotations
 
 import codecs
+import locale
 import os
 import re
 from zlib import crc32 as _crc32
@@ -19,18 +20,21 @@ script = os.path.realpath(os.path.join(here, "..", "src", "virtualenv.py"))
 gzip = codecs.lookup("zlib")
 b64 = codecs.lookup("base64")
 
-file_regex = re.compile(r'# file (.*?)\n([a-zA-Z][a-zA-Z0-9_]+) = convert\(\n {4}"""\n(.*?)"""\n\)', re.S)
+file_regex = re.compile(r'# file (.*?)\n([a-zA-Z][a-zA-Z0-9_]+) = convert\(\n {4}"""\n(.*?)"""\n\)', re.DOTALL)
 file_template = '# file {filename}\n{variable} = convert(\n    """\n{data}"""\n)'
 
 
 def rebuild(script_path):
-    with open(script_path) as current_fh:
+    encoding = (
+        locale.getencoding() if hasattr(locale, "getencoding") else locale.getpreferredencoding(do_setlocale=False)
+    )
+    with script_path.open(encoding=encoding) as current_fh:
         script_content = current_fh.read()
     script_parts = []
     match_end = 0
     next_match = None
-    _count, did_update = 0, False
-    for _count, next_match in enumerate(file_regex.finditer(script_content)):
+    count, did_update = 0, False
+    for count, next_match in enumerate(file_regex.finditer(script_content)):  # noqa: B007
         script_parts += [script_content[match_end : next_match.start()]]
         match_end = next_match.end()
         filename, variable_name, previous_encoded = next_match.group(1), next_match.group(2), next_match.group(3)
@@ -42,14 +46,14 @@ def rebuild(script_path):
     script_parts += [script_content[match_end:]]
     new_content = "".join(script_parts)
 
-    report(1 if not _count or did_update else 0, new_content, next_match, script_content, script_path)
+    report(1 if not count or did_update else 0, new_content, next_match, script_content, script_path)
 
 
 def handle_file(previous_content, filename, variable_name, previous_encoded):
     print(f"Found file {filename}")  # noqa: T201
     current_path = os.path.realpath(os.path.join(here, "..", "src", "virtualenv_embedded", filename))
     _, file_type = os.path.splitext(current_path)
-    keep_line_ending = file_type in (".bat",)
+    keep_line_ending = file_type == ".bat"
     with open(current_path, encoding="utf-8", newline="" if keep_line_ending else None) as current_fh:
         current_text = current_fh.read()
     current_crc = crc32(current_text)
@@ -68,8 +72,7 @@ def handle_file(previous_content, filename, variable_name, previous_encoded):
 def report(exit_code, new, next_match, current, script_path):
     if new != current:
         print("Content updated; overwriting... ", end="")  # noqa: T201
-        with open(script_path, "w") as current_fh:
-            current_fh.write(new)
+        script_path.write_bytes(new)
         print("done.")  # noqa: T201
     else:
         print("No changes in content")  # noqa: T201
