@@ -15,7 +15,7 @@ from threading import Thread
 STRICT = "UPGRADE_ADVISORY" not in os.environ
 
 BUNDLED = ["pip", "setuptools", "wheel"]
-SUPPORT = [(3, i) for i in range(8, 15)]
+SUPPORT = [(3, i) for i in range(8, 16)]
 DEST = Path(__file__).resolve().parents[1] / "src" / "virtualenv" / "seed" / "wheels" / "embed"
 
 
@@ -23,6 +23,8 @@ def download(ver, dest, package):
     subprocess.call(
         [
             sys.executable,
+            "-W",
+            "ignore::EncodingWarning",
             "-m",
             "pip",
             "--disable-pip-version-check",
@@ -109,10 +111,13 @@ def run():  # noqa: C901, PLR0912
 
 
         def get_embed_wheel(distribution, for_py_version):
-            path = BUNDLE_FOLDER / (BUNDLE_SUPPORT.get(for_py_version, {{}}) or BUNDLE_SUPPORT[MAX]).get(distribution)
+            mapping = BUNDLE_SUPPORT.get(for_py_version, {{}}) or BUNDLE_SUPPORT[MAX]
+            wheel_file = mapping.get(distribution)
+            if wheel_file is None:
+                return None
+            path = BUNDLE_FOLDER / wheel_file
             return Wheel.from_path(path)
 
-
         __all__ = [
             "get_embed_wheel",
             "BUNDLE_SUPPORT",
